# BRANCHES / VERSIONS
#
# Once a schema is commited to a branch, it is not upgraded.  This means that
# the following versions are the highest versions for any given branch:
# EL5: 2.2.18
# EL6: 3.0.2
# EL7: current (3.2.x autoupgrades any 3.1.x schema)
# F19: 3.0.2
# F20: 3.0.2
# F21: current (3.2.x autoupgrades any 3.1.x schema)
#
# Important fixes should be backported.
#

# enable PIE flags
%global         _hardened_build 1

%define         services dbmail-imapd dbmail-pop3d dbmail-lmtpd dbmail-timsieved

Name:           dbmail
Version:        3.2.3
Release:        1%{?dist}
Summary:        A database backed mail storage system

Group:          System Environment/Daemons
# db_getopot.c is licensed MIT
License:        GPLv2+ and MIT
URL:            http://www.dbmail.org
Source0:        http://www.dbmail.org/download/3.0/dbmail-%{version}.tar.gz
Source1:        dbmail-imapd.service
Source2:        dbmail-pop3d.service
Source3:        dbmail-lmtpd.service
Source4:        dbmail-timsieved.service
Source5:        dbmail.cron
Source6:        dbmail.logrotate
Source7:        README.fedora
Source8:        dbmail.sysconfig

Patch0:         dbmail-3.0.2-gthread.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  gmime-devel > 2.4, systemd
BuildRequires:  fileutils, openssl-devel >= 0.9.7a
BuildRequires:  glib2-devel >= 2.16, mhash-devel
BuildRequires:  libsieve-devel >= 2.1.13, libzdb-devel >= 2.4, libevent-devel
BuildRequires:  openldap-devel
BuildRequires:  asciidoc, xmlto

Requires:       glib2 >= 2.8, logrotate, dailyjobs
Requires:       /usr/sbin/sendmail
# libzdb 2.5 is broken for postgresql
Requires:       libzdb >= 2.6
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# Always require sqlite so a "out of the box" experience is possible.
Requires:       sqlite

# Keep the obsoletes for upgrades
Obsoletes:      dbmail-sqlite < 2.2.5
Obsoletes:      dbmail-pgsql < 2.3.6
Obsoletes:      dbmail-mysql < 2.3.6
# Try to minimize dependency issues
Provides:       dbmail-sqlite = %{version}
Provides:       dbmail-pgsql = %{version}
Provides:       dbmail-mysql = %{version}

Requires(pre):  shadow-utils

%description
Dbmail is the name of a group of programs that enable the possiblilty of
storing and retrieving mail messages from a database.

Currently dbmail supports the following database backends via libzdb:
MySQL
PostgreSQL
SQLite

Please see /usr/share/doc/dbmail-*/README.fedora for specific information on
installation and configuration in Fedora.

%prep
%setup -q

%if 0%{?rhel} && 0%{?rhel} > 5
# Temporary patch - gmime is not adding flags for gthread; add to
# glib for now
%patch0 -p1 -b .gthread
%endif

# we don't need README.solaris and we don't want it caught up in the %%doc
# README* wildcard - but we do want our shiny new README.fedora file to be
# installed
rm -f README.solaris
install -p -m 644 %SOURCE7 .

# make a couple of changes to the default dbmail.conf file:
# 1. default driver/authdriver sqlite/sql
# 2. effective uid/gid to dbmail/dbmail
sed -i 's/\(^driver\W*=\)\(\W*$\)/\1 sqlite/' dbmail.conf
sed -i -e 's,\(^db\W*=\)\(.*$\),\1 %{_localstatedir}/lib/dbmail/dbmail.db,'   \
       -e 's/\(^authdriver\W*=\)\(\W*$\)/\1 sql/'                             \
       -e 's/\(^EFFECTIVE_USER\W*=\)\(.*$\)/\1 dbmail/'                       \
       -e 's/\(^EFFECTIVE_GROUP\W*=\)\(.*$\)/\1 dbmail/' dbmail.conf

%if 0%{?fedora} && 0%{?fedora} > 13
sed -i 's/gmime-2.4/gmime-2.6/g' configure
%endif

%build
export CFLAGS="%{optflags} -I/usr/include/zdb"
%configure --disable-rpath \
           --disable-static \
           --with-ldap \
           --with-sieve \
           --enable-manpages

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man{1,5,8}
mkdir -p $RPM_BUILD_ROOT/%{_unitdir}
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/cron.daily
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/dbmail
install -p -m 644 %SOURCE1 $RPM_BUILD_ROOT/%{_unitdir}
install -p -m 644 %SOURCE2 $RPM_BUILD_ROOT/%{_unitdir}
install -p -m 644 %SOURCE3 $RPM_BUILD_ROOT/%{_unitdir}
install -p -m 644 %SOURCE4 $RPM_BUILD_ROOT/%{_unitdir}
install -p -m 755 %SOURCE5 $RPM_BUILD_ROOT/%{_sysconfdir}/cron.daily/dbmail
install -p -m 644 %SOURCE6 $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/dbmail
install -p -m 644 %SOURCE8 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/dbmail 
install -p -m 600 dbmail.conf $RPM_BUILD_ROOT/%{_sysconfdir}/
install -p -m 644 man/*1 $RPM_BUILD_ROOT/%{_mandir}/man1/
install -p -m 644 man/*5 $RPM_BUILD_ROOT/%{_mandir}/man5/
install -p -m 644 man/*8 $RPM_BUILD_ROOT/%{_mandir}/man8/
# remove libtool archives and -devel type stuff (but leave loadable modules)
find $RPM_BUILD_ROOT -name \*\.la -print | xargs rm -f
rm -f $RPM_BUILD_ROOT/%{_libdir}/dbmail/libdbmail.so

%clean
rm -rf $RPM_BUILD_ROOT

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
  useradd -r -M -g %{name} -d / -s /sbin/nologin \
  -c "DBMail Daemon" %{name}
exit 0

%post
for s in %services; do
  %systemd_post $s.service
done
/sbin/ldconfig

%preun
for s in %services; do
  %systemd_preun $s.service
done

%postun
/sbin/ldconfig
for s in %services; do
  %systemd_preun $s.service
done

%files
%defattr(-,root,root,-)
%doc AUTHORS BUGS ChangeLog COPYING INSTALL README* THANKS UPGRADING sql dbmail.schema
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%dir %{_libdir}/dbmail
%{_libdir}/dbmail/libauth_sql*
%{_libdir}/dbmail/libdbmail*
%{_libdir}/dbmail/libsort_sieve*
%config(noreplace) %{_sysconfdir}/dbmail.conf
%{_unitdir}/dbmail-*.service
%{_sysconfdir}/cron.daily/dbmail
%config(noreplace) %{_sysconfdir}/sysconfig/dbmail
%config(noreplace) %{_sysconfdir}/logrotate.d/dbmail
%dir %attr(0775,root,dbmail) /var/lib/dbmail

%package auth-ldap
Summary:        A database backed mail storage system - ldap authentication plugin
Group:          System Environment/Daemons
Requires:       dbmail = %{version}-%{release}, openldap

%description auth-ldap
This is the auth-ldap libraries for authentication against a ldap server with
dbmail.

%files auth-ldap
%defattr(-,root,root,-)
%attr(-,root,root) %{_libdir}/dbmail/libauth_ldap*


%changelog
* Fri Feb 27 2015 Bernard Johnson <bjohnson@symetrix.com> - 3.2.3-1
- v 3.2.3
- Introduce new systemd-rpm macros in dbmail spec file (bz #850081)


* Wed Sep 17 2014 Bernard Johnson <bjohnson@symetrix.com> - 3.2.0-1
- v 3.2.0

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Mar 22 2014 Bernard Johnson <bjohnson@symetrix.com> - 3.1.13-1
- v 3.1.13

* Fri Mar 14 2014 Bernard Johnson <bjohnson@symetrix.com> - 3.1.10-2
- rebuild against newer libzdb

* Sat Feb 22 2014 Bernard Johnson <bjohnson@symetrix.com> - 3.1.10-1
- v 3.1.10
- prune out old changelog entries prior to 3.0
- nonsense in /etc/sysconfig/dbmail (bz #818379)
- Please update this package as it's really old. (bz #1004368)
- dbmail package should be built with PIE flags (bz #955101)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Nov 23 2012 Marcela Mašláňová <mmaslano@redhat.com> - 3.0.2-5
- The requirement on vixie-cron is not correct anymore. The dailyjobs will be
  used as virtual requirement since now. #879550

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Apr 20 2012 Jon Ciesla <limburgher@gmail.com> - 3.0.2-3
- Migrate to systemd, BZ 722341.

* Mon Mar 19 2012 Bernard Johnson <bjohnson@symetrix.com> - 3.0.2-2
- EL patch reworked for gthread only

* Sun Mar 18 2012 Bernard Johnson <bjohnson@symetrix.com> - 3.0.2-1
- 3.0.2

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.0-0.7.rc3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Aug 15 2011 Bernard Johnson <bjohnson@symetrix.com> - 3.0.0-0.6.rc3
- 3.0.0-rc3

* Mon Apr 25 2011 Tom Callaway <spot@fedoraproject.org> - 3.0.0-0.5.rc2
- update to rc2
- apply compile fix from upstream git (patch3)

* Mon Feb 21 2011 Bernard Johnson <bjohnson@symetrix.com> - 3.0.0-0.4.rc1
- try rebuild against libevent ABI v2

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.0-0.3.rc1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 22 2011 Bernard Johnson <bjohnson@symetrix.com> - 3.0.0.0.2.rc1
- patch to glib package config flags for el6

* Sat Jan 15 2011 Bernard Johnson <bjohnson@symetrix.com> - 3.0.0-0.1.rc1
- v 3.0.0 release candidate 1
